@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Rubric::WebApp;
 {
-  $Rubric::WebApp::VERSION = '0.150';
+  $Rubric::WebApp::VERSION = '0.151';
 }
 # ABSTRACT: the web interface to Rubric
 
@@ -689,11 +689,13 @@ sub _post_form_contents {
     for qw(entryid uri title description tags body);
 
   for (qw(uri title description body tags)) {
+    my $decoded;
     my $ok = eval {
-      decode_utf8($form{$_}, Encode::FB_CROAK | Encode::LEAVE_SRC);
+      $decoded = decode_utf8($form{$_}, Encode::FB_CROAK | Encode::LEAVE_SRC);
       1;
     };
-    $error{$_} = "Invalid UTF-8 characters in $_." unless $ok;
+    $error{$_} = "Invalid characters in $_." unless $ok;
+    $form{$_} = $decoded if $ok;
   }
 
   eval { $form{uri} = URI->new($form{uri})->canonical; };
@@ -842,7 +844,7 @@ Rubric::WebApp - the web interface to Rubric
 
 =head1 VERSION
 
-version 0.150
+version 0.151
 
 =head1 SYNOPSIS
 
